==> haskell-semirings-0.6-57-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-semirings.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 semirings
version:              0.6
visibility:           public
id:                   semirings-0.6-5eQ9KXvq8h16WNhr0oP2tU
key:                  semirings-0.6-5eQ9KXvq8h16WNhr0oP2tU
license:              BSD-3-Clause
copyright:            Copyright (C) 2018 chessai
maintainer:           chessai <chessai1996@gmail.com>
author:               chessai
stability:            provisional
homepage:             http://github.com/chessai/semirings
synopsis:             two monoids as one, in holy haskimony
description:
    Haskellers are usually familiar with monoids and semigroups. A monoid has an appending operation `<>` (or `mappend`),
    and an identity element, `mempty`. A semigroup has an appending `<>` operation, but does not require a `mempty` element.

    A Semiring has two appending operations, `plus` and `times`, and two respective identity elements, `zero` and `one`.

    More formally, a Semiring R is a set equipped with two binary relations `+` and `*`, such that:

    (R,+) is a commutative monoid with identity element 0,

    (R,*) is a monoid with identity element 1,

    (*) left and right distributes over addition, and

    multiplication by '\''0'\'' annihilates R.

category:             Algebra, Data, Data Structures, Math, Maths, Mathematics
abi:                  76b2eb886110023584740b047b5fe778
exposed:              True
exposed-modules:
    Data.Euclidean Data.Field Data.Semiring Data.Semiring.Generic
    Data.Semiring.Tropical Data.Star

import-dirs:          /usr/lib/ghc-9.0.2/site-local/semirings-0.6
library-dirs:         /usr/lib/ghc-9.0.2/site-local/semirings-0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-semirings
hs-libraries:         HSsemirings-0.6-5eQ9KXvq8h16WNhr0oP2tU
depends:
    base-4.15.1.0 base-compat-batteries-0.12.1-JgYG4bcnReN13a68eTZ772
    containers-0.6.4.1 hashable-1.4.0.2-JOg1RVWjzKq3dbebA7sIP
    unordered-containers-0.2.19.1-ApErtw5neJn6AjDg9YQBMs

haddock-interfaces:   /usr/share/doc/haskell-semirings/html/semirings.haddock
haddock-html:         /usr/share/doc/haskell-semirings/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-semirings-0.6-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-semirings.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 semirings
version:              0.6
visibility:           public
id:                   semirings-0.6-2l0UEnaizDK72SY8U0g0rM
key:                  semirings-0.6-2l0UEnaizDK72SY8U0g0rM
license:              BSD-3-Clause
copyright:            Copyright (C) 2018 chessai
maintainer:           chessai <chessai1996@gmail.com>
author:               chessai
stability:            provisional
homepage:             http://github.com/chessai/semirings
synopsis:             two monoids as one, in holy haskimony
description:
    Haskellers are usually familiar with monoids and semigroups. A monoid has an appending operation `<>` (or `mappend`),
    and an identity element, `mempty`. A semigroup has an appending `<>` operation, but does not require a `mempty` element.

    A Semiring has two appending operations, `plus` and `times`, and two respective identity elements, `zero` and `one`.

    More formally, a Semiring R is a set equipped with two binary relations `+` and `*`, such that:

    (R,+) is a commutative monoid with identity element 0,

    (R,*) is a monoid with identity element 1,

    (*) left and right distributes over addition, and

    multiplication by '\''0'\'' annihilates R.

category:             Algebra, Data, Data Structures, Math, Maths, Mathematics
abi:                  9331b0980a7e5dccf6c7935406a4c86d
exposed:              True
exposed-modules:
    Data.Euclidean Data.Field Data.Semiring Data.Semiring.Generic
    Data.Semiring.Tropical Data.Star

import-dirs:          /usr/lib/ghc-9.0.2/site-local/semirings-0.6
library-dirs:         /usr/lib/ghc-9.0.2/site-local/semirings-0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-semirings
hs-libraries:         HSsemirings-0.6-2l0UEnaizDK72SY8U0g0rM
depends:
    base-4.15.1.0 base-compat-batteries-0.12.1-Ji02T1ore7MDoGMdpwyn03
    containers-0.6.4.1 hashable-1.4.0.2-J44BDnT4N4jIfsjZsKg5ZQ
    unordered-containers-0.2.19.1-BhRjg5By7kU7pLGfSxEo3F

haddock-interfaces:   /usr/share/doc/haskell-semirings/html/semirings.haddock
haddock-html:         /usr/share/doc/haskell-semirings/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
